@@ -209,11 +209,20 @@ void Conditional::set(struct timespec *ts, timeout_t msec)
 Semaphore::Semaphore(unsigned limit) :
 Conditional()
 {
-    assert(limit > 0);
+	waits = 0;
+	count = limit;
+	used = 0;
+}
 
-    count = limit;
-    waits = 0;
-    used = 0;
+Semaphore::Semaphore(unsigned limit, unsigned avail) :
+Conditional()
+{
+	assert(limit > 0);
+	assert(avail <= limit);
+
+	waits = 0;
+	count = limit;
+	used = limit - avail;
 }
 
 void Semaphore::_share(void)
@@ -237,8 +246,10 @@ bool Semaphore::wait(timeout_t timeout)
         ++waits;
         result = Conditional::wait(&ts);
         --waits;
+		if(!count)
+			break;
     }
-    if(result)
+    if(result && count)
         ++used;
     unlock();
     return result;
@@ -252,7 +263,8 @@ void Semaphore::wait(void)
         Conditional::wait();
         --waits;
     }
-    ++used;
+	if(count)
+	    ++used;
     unlock();
 }
 
@@ -261,8 +273,12 @@ void Semaphore::release(void)
     lock();
     if(used)
         --used;
-    if(waits)
-        signal();
+    if(waits) {
+		if(count)
+	        signal();
+		else
+			broadcast();
+	}
     unlock();
 }
 
