@@ -251,22 +251,25 @@ public:
     void signal(bool broadcast);
 
     inline void enterMutex(void)
-        {ucommon::Conditional::lock();};
+        {ucommon::Conditional::lock();}
 
     inline void leaveMutex(void)
-        {ucommon::Conditional::unlock();};
+        {ucommon::Conditional::unlock();}
 };
 
 class __EXPORT Semaphore : private ucommon::Semaphore
 {
 public:
-    inline Semaphore(unsigned size=0) : ucommon::Semaphore(size) {};
+    inline Semaphore(unsigned size = 0) : ucommon::Semaphore(size) {};
 
-    inline bool wait(timeout_t timeout = 0)
-        {return ucommon::Semaphore::wait(timeout);};
+    inline bool wait(timeout_t timeout)
+        {return ucommon::Semaphore::wait(timeout);}
+
+    inline void wait(void)
+        {ucommon::Semaphore::wait();}
 
     inline void post(void)
-        {ucommon::Semaphore::release();};
+        {ucommon::Semaphore::release();}
 };
 
 /**
@@ -310,19 +313,22 @@ public:
 class __EXPORT Event : private ucommon::TimedEvent
 {
 public:
-    inline Event() : TimedEvent() {};
+    inline Event() : ucommon::TimedEvent() {};
 
     inline void wait(void)
-        {ucommon::TimedEvent::wait(Timer::inf);};
+        {ucommon::TimedEvent::wait();}
 
     inline bool wait(timeout_t timeout)
-        {return ucommon::TimedEvent::wait(timeout);};
+        {return ucommon::TimedEvent::wait(timeout);}
 
     inline void signal(void)
-        {ucommon::TimedEvent::signal();};
+        {ucommon::TimedEvent::signal();}
 
     inline void reset(void)
-        {ucommon::TimedEvent::reset();};
+        {ucommon::TimedEvent::reset();}
+
+    inline void set(timeout_t timeout = 0)
+        {ucommon::TimedEvent::set(timeout);}
 };
 
 class __EXPORT Thread : protected ucommon::JoinableThread
